===============
Example recipes
===============

Each example covers a specific aspect of working with cw-EPR spectra, is presented on its separate page, and comes with a complete, working recipe. For a bit of background on how to process and analyse cw-EPR data, see the :doc:`cw-EPR primer <../cwepr/index>`.


.. toctree::
    :maxdepth: 1

    first-overview
    power-sweep-analysis
    rotation-pattern
